@@ -34,8 +34,10 @@ class multiRequester:
                                        headers=headers)
                 return res
             except Exception as e:
-                if rand_proxy:
+                try:
                     rand_proxy.setWorking(False)
+                except:
+                    pass
 
     def get_many(self, urls):
         tasks = []
